@@ -24,6 +24,7 @@ class MetadataDecoder(ScaleDecoder):
         self.metadata = None
         self.call_index = None
         self.event_index = None
+        self.error_index = {}
         super().__init__(data, **kwargs)
 
     def process(self):
@@ -53,6 +54,20 @@ class MetadataDecoder(ScaleDecoder):
             self.call_index = self.metadata.call_index
             self.event_index = self.metadata.event_index
 
+            # Create error index
+            if self.version.index >= 12:
+                for module in self.metadata.modules:
+                    if len(module.errors or []) > 0:
+                        for idx, error in enumerate(module.errors):
+                            self.error_index[f'{module.index}-{idx}'] = error
+            else:
+                error_module_index = 0
+                for module in self.metadata.modules:
+                    if len(module.errors or []) > 0:
+                        for idx, error in enumerate(module.errors):
+                            self.error_index[f'{error_module_index}-{idx}'] = error
+                        error_module_index += 1
+
             return self.metadata.value
 
         else:
@@ -67,16 +82,19 @@ class MetadataDecoder(ScaleDecoder):
 
             return self.metadata.value
 
+    def get_module_error(self, module_index, error_index):
+        return self.error_index.get(f'{module_index}-{error_index}')
+
 
 class MetadataV4Decoder(ScaleDecoder):
 
-    def __init__(self, data, sub_type=None):
+    def __init__(self, data, sub_type=None, **kwargs):
         self.version = None
         self.modules = []
         self.call_index = {}
         self.event_index = {}
 
-        super().__init__(data, sub_type)
+        super().__init__(data, sub_type, **kwargs)
 
     def process(self):
         result_data = {
@@ -231,13 +249,13 @@ class MetadataV4ModuleStorage(ScaleType):
 
 class MetadataV5Decoder(ScaleDecoder):
 
-    def __init__(self, data, sub_type=None):
+    def __init__(self, data, sub_type=None, **kwargs):
         self.version = None
         self.modules = []
         self.call_index = {}
         self.event_index = {}
 
-        super().__init__(data, sub_type)
+        super().__init__(data, sub_type, **kwargs)
 
     def process(self):
         result_data = {
@@ -276,7 +294,7 @@ class MetadataV5Decoder(ScaleDecoder):
 
 class MetadataV5Module(ScaleType):
 
-    def __init__(self, data, sub_type=None):
+    def __init__(self, data, sub_type=None, **kwargs):
         self.name = None
         self.prefix = None
         self.call_index = None
@@ -288,7 +306,7 @@ class MetadataV5Module(ScaleType):
         self.events = None
         self.constants = []
         self.errors = []
-        super().__init__(data, sub_type)
+        super().__init__(data, sub_type, **kwargs)
 
     def get_identifier(self):
         return self.name.lower()
@@ -391,13 +409,13 @@ class MetadataV5ModuleStorage(ScaleType):
 
 class MetadataV6Decoder(ScaleDecoder):
 
-    def __init__(self, data, sub_type=None):
+    def __init__(self, data, sub_type=None, **kwargs):
         self.version = None
         self.modules = []
         self.call_index = {}
         self.event_index = {}
 
-        super().__init__(data, sub_type)
+        super().__init__(data, sub_type, **kwargs)
 
     def process(self):
         result_data = {
@@ -525,13 +543,13 @@ class MetadataV6ModuleConstants(ScaleType):
 
 class MetadataV7Decoder(ScaleDecoder):
 
-    def __init__(self, data, sub_type=None):
+    def __init__(self, data, sub_type=None, **kwargs):
         self.version = None
         self.modules = []
         self.call_index = {}
         self.event_index = {}
 
-        super().__init__(data, sub_type)
+        super().__init__(data, sub_type, **kwargs)
 
     def process(self):
         result_data = {
@@ -711,13 +729,13 @@ class MetadataV7ModuleConstants(MetadataV6ModuleConstants):
 
 class MetadataV8Decoder(ScaleDecoder):
 
-    def __init__(self, data, sub_type=None):
+    def __init__(self, data, sub_type=None, **kwargs):
         self.version = None
         self.modules = []
         self.call_index = {}
         self.event_index = {}
 
-        super().__init__(data, sub_type)
+        super().__init__(data, sub_type, **kwargs)
 
     def process(self):
         result_data = {
@@ -837,13 +855,13 @@ class MetadataModuleError(ScaleType):
 
 class MetadataV9Decoder(ScaleDecoder):
 
-    def __init__(self, data, sub_type=None):
+    def __init__(self, data, sub_type=None, **kwargs):
         self.version = None
         self.modules = []
         self.call_index = {}
         self.event_index = {}
 
-        super().__init__(data, sub_type)
+        super().__init__(data, sub_type, **kwargs)
 
     def process(self):
         result_data = {
@@ -882,13 +900,13 @@ class MetadataV9Decoder(ScaleDecoder):
 
 class MetadataV10Decoder(ScaleDecoder):
 
-    def __init__(self, data, sub_type=None):
+    def __init__(self, data, sub_type=None, **kwargs):
         self.version = None
         self.modules = []
         self.call_index = {}
         self.event_index = {}
 
-        super().__init__(data, sub_type)
+        super().__init__(data, sub_type, **kwargs)
 
     def process(self):
         result_data = {
@@ -927,13 +945,13 @@ class MetadataV10Decoder(ScaleDecoder):
 
 class MetadataV11Decoder(ScaleDecoder):
 
-    def __init__(self, data, sub_type=None):
+    def __init__(self, data, sub_type=None, **kwargs):
         self.version = None
         self.modules = []
         self.call_index = {}
         self.event_index = {}
 
-        super().__init__(data, sub_type)
+        super().__init__(data, sub_type, **kwargs)
 
     def process(self):
         result_data = {
@@ -973,13 +991,13 @@ class MetadataV11Decoder(ScaleDecoder):
 
 class MetadataV12Decoder(ScaleDecoder):
 
-    def __init__(self, data, sub_type=None):
+    def __init__(self, data, sub_type=None, **kwargs):
         self.version = None
         self.modules = []
         self.call_index = {}
         self.event_index = {}
 
-        super().__init__(data, sub_type)
+        super().__init__(data, sub_type, **kwargs)
 
     def process(self):
         result_data = {
@@ -1085,13 +1103,13 @@ class MetadataV12Module(ScaleType):
 
 class MetadataV3Decoder(ScaleDecoder):
 
-    def __init__(self, data, sub_type=None):
+    def __init__(self, data, sub_type=None, **kwargs):
         self.version = None
         self.modules = []
         self.call_index = {}
         self.event_index = {}
 
-        super().__init__(data, sub_type)
+        super().__init__(data, sub_type, **kwargs)
 
     def process(self):
         result_data = {
@@ -1130,13 +1148,13 @@ class MetadataV3Decoder(ScaleDecoder):
 
 class MetadataV2Decoder(ScaleDecoder):
 
-    def __init__(self, data, sub_type=None):
+    def __init__(self, data, sub_type=None, **kwargs):
         self.version = None
         self.modules = []
         self.call_index = {}
         self.event_index = {}
 
-        super().__init__(data, sub_type)
+        super().__init__(data, sub_type, **kwargs)
 
     def process(self):
         result_data = {
@@ -1175,13 +1193,13 @@ class MetadataV2Decoder(ScaleDecoder):
 
 class MetadataV1Decoder(ScaleDecoder):
 
-    def __init__(self, data, sub_type=None):
+    def __init__(self, data, sub_type=None, **kwargs):
         self.version = None
         self.modules = []
         self.call_index = {}
         self.event_index = {}
 
-        super().__init__(data, sub_type)
+        super().__init__(data, sub_type, **kwargs)
 
     def process(self):
         result_data = {
@@ -1220,7 +1238,7 @@ class MetadataV1Decoder(ScaleDecoder):
 
 class MetadataV0Decoder(ScaleDecoder):
 
-    def __init__(self, data, sub_type=None):
+    def __init__(self, data, sub_type=None, **kwargs):
         self.version = None
         self.events_modules = []
         self.modules = []
@@ -1228,7 +1246,7 @@ class MetadataV0Decoder(ScaleDecoder):
         self.call_index = {}
         self.event_index = {}
 
-        super().__init__(data, sub_type)
+        super().__init__(data, sub_type, **kwargs)
 
     def process(self):
         result_data = {
